import { getGraphQLParameters, processRequest, } from "graphql-helix";
export function createGQLHandler(config) {
    const handler = async (event, context) => {
        const request = {
            body: event.body ? JSON.parse(event.body) : undefined,
            query: event.queryStringParameters,
            method: event.requestContext.http.method,
            headers: event.headers,
        };
        const { operationName, query, variables } = getGraphQLParameters(request);
        // Validate and execute the query
        const result = await processRequest({
            operationName,
            query,
            variables,
            request,
            schema: config.schema,
            formatPayload: config.formatPayload,
            contextFactory: async (execution) => {
                if (config.context) {
                    return config.context({
                        event: event,
                        context,
                        execution,
                    });
                }
                return undefined;
            },
        });
        if (result.type === "RESPONSE") {
            return {
                statusCode: result.status,
                body: JSON.stringify(result.payload),
                headers: Object.fromEntries(result.headers.map((h) => [h.name, h.value])),
            };
        }
        return {
            statusCode: 500,
        };
    };
    return handler;
}
